==> sleepanalyser_1.8-36.tar.gz: sleepanalyser-1.8/src/opt/SleepAnalyser/lib/mylib.cpp <==
#include "mylib.hpp"

namespace __mylib__ {

str *const_0;

list<__ss_int> *arFiltertest, *arTest;
str *__name__;


__ss_bool IsCompiled() {
    __ss_bool r;

    r = True;
    return r;
}

list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max, __ss_int min) {
    list<__ss_int> *ar_ret;
    __ss_int __0, __1, __2, __3, __4, __5, i, len_filter, p, value;

    len_filter = len(filter);
    ar_ret = ((new list<__ss_int>(1, 0)))->__mul__((l+len_filter));

    FAST_FOR(i,0,(l-1),1,0,1)
        value = ar->__getfast__(i);

        FAST_FOR(p,0,(len_filter-1),1,2,3)
            ar_ret->__setitem__(((i+p)-shift), (ar_ret->__getfast__(((i+p)-shift))+(value*filter->__getfast__(p))));
        END_FOR

    END_FOR


    FAST_FOR(i,0,(l-1),1,4,5)
        value = __divs(ar_ret->__getfast__(i), (scale*100));
        if ((value>max)) {
            ar_ret->__setitem__(i, max);
        }
        else if ((value<min)) {
            ar_ret->__setitem__(i, min);
        }
        else {
            ar_ret->__setitem__(i, value);
        }
    END_FOR

    return ar_ret;
}

void __init() {
    const_0 = new str("__main__");

    __name__ = new str("mylib");

    if (__eq(__name__, const_0)) {
        IsCompiled();
        arTest = (new list<__ss_int>(9, 1, 2, 3, 4, 5, 6, 7, 8, 9));
        arFiltertest = (new list<__ss_int>(3, 1, 2, 3));
        sleep_filter(arTest, 1, arFiltertest, 1, 20, 120, 13);
    }
}

} // module namespace

/* extension module glue */

extern "C" {
#include <Python.h>
#include <structmember.h>

PyObject *__ss_mod_mylib;

namespace __mylib__ { /* XXX */
PyObject *Global_mylib_IsCompiled(PyObject *self, PyObject *args, PyObject *kwargs) {
    try {

        return __to_py(__mylib__::IsCompiled());

    } catch (Exception *e) {
        PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
        return 0;
    }
}

PyObject *Global_mylib_sleep_filter(PyObject *self, PyObject *args, PyObject *kwargs) {
    try {
        list<__ss_int> *arg_0 = __ss_arg<list<__ss_int> *>("ar", 0, 0, NULL, args, kwargs);
        __ss_int arg_1 = __ss_arg<__ss_int >("l", 1, 0, NULL, args, kwargs);
        list<__ss_int> *arg_2 = __ss_arg<list<__ss_int> *>("filter", 2, 0, NULL, args, kwargs);
        __ss_int arg_3 = __ss_arg<__ss_int >("shift", 3, 0, NULL, args, kwargs);
        __ss_int arg_4 = __ss_arg<__ss_int >("scale", 4, 0, NULL, args, kwargs);
        __ss_int arg_5 = __ss_arg<__ss_int >("max", 5, 0, NULL, args, kwargs);
        __ss_int arg_6 = __ss_arg<__ss_int >("min", 6, 0, NULL, args, kwargs);

        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3, arg_4, arg_5, arg_6));

    } catch (Exception *e) {
        PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
        return 0;
    }
}

static PyNumberMethods Global_mylib_as_number = {
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
};

static PyMethodDef Global_mylibMethods[] = {
    {(char *)"__newobj__", (PyCFunction)__ss__newobj__, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {(char *)"IsCompiled", (PyCFunction)Global_mylib_IsCompiled, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {(char *)"sleep_filter", (PyCFunction)Global_mylib_sleep_filter, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {NULL}
};

PyMODINIT_FUNC initmylib(void) {
    __shedskin__::__init();
    __mylib__::__init();

    __ss_mod_mylib = Py_InitModule((char *)"mylib", Global_mylibMethods);
    if(!__ss_mod_mylib)
        return;


    addmylib();

}

PyMODINIT_FUNC addmylib(void) {
    PyModule_AddObject(__ss_mod_mylib, (char *)"arTest", __to_py(__mylib__::arTest));
    PyModule_AddObject(__ss_mod_mylib, (char *)"arFiltertest", __to_py(__mylib__::arFiltertest));

}

} // namespace __mylib__

} // extern "C"
int main(int, char **) {
    __shedskin__::__init();
    __shedskin__::__start(__mylib__::__init);
}

==> sleepanalyser_1.8-47.tar.gz: sleepanalyser-1.8/src/opt/SleepAnalyser/lib/mylib.cpp <==
#include "mylib.hpp"

namespace __mylib__ {

str *const_0;

list<__ss_int> *arFiltertest, *arTest;
str *__name__;


__ss_bool IsCompiled() {
    __ss_bool r;

    r = True;
    return r;
}

list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale, __ss_int max) {
    list<__ss_int> *ar_ret;
    __ss_int __0, __1, __2, __3, __4, __5, i, len_filter, p, value;

    len_filter = len(filter);
    value = 1;
    ar_ret = ((new list<__ss_int>(1, 0)))->__mul__((l+len_filter));

    FAST_FOR(i,0,(l-1),1,0,1)
        value = ar->__getfast__(i);

        FAST_FOR(p,0,(len_filter-1),1,2,3)
            ar_ret->__setitem__(((i+p)-shift), (ar->__getfast__(((i+p)-shift))+(value*filter->__getfast__(p))));
        END_FOR

    END_FOR


    FAST_FOR(i,0,(l-1),1,4,5)
        value = __divs(ar_ret->__getfast__(i), (scale*100));
        if ((value>max)) {
            ar_ret->__setitem__(i, max);
        }
        else if ((value<13)) {
            ar_ret->__setitem__(i, 13);
        }
        else {
            ar_ret->__setitem__(i, value);
        }
    END_FOR

    return ar_ret;
}

void __init() {
    const_0 = new str("__main__");

    __name__ = new str("mylib");

    if (__eq(__name__, const_0)) {
        IsCompiled();
        arTest = (new list<__ss_int>(2, 1, 2));
        arFiltertest = (new list<__ss_int>(3, 1, 2, 3));
        sleep_filter(arTest, 1, arFiltertest, 1, 20, 120);
    }
}

} // module namespace

/* extension module glue */

extern "C" {
#include <Python.h>
#include <structmember.h>

PyObject *__ss_mod_mylib;

namespace __mylib__ { /* XXX */
PyObject *Global_mylib_IsCompiled(PyObject *self, PyObject *args, PyObject *kwargs) {
    try {

        return __to_py(__mylib__::IsCompiled());

    } catch (Exception *e) {
        PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
        return 0;
    }
}

PyObject *Global_mylib_sleep_filter(PyObject *self, PyObject *args, PyObject *kwargs) {
    try {
        list<__ss_int> *arg_0 = __ss_arg<list<__ss_int> *>("ar", 0, 0, NULL, args, kwargs);
        __ss_int arg_1 = __ss_arg<__ss_int >("l", 1, 0, NULL, args, kwargs);
        list<__ss_int> *arg_2 = __ss_arg<list<__ss_int> *>("filter", 2, 0, NULL, args, kwargs);
        __ss_int arg_3 = __ss_arg<__ss_int >("shift", 3, 0, NULL, args, kwargs);
        __ss_int arg_4 = __ss_arg<__ss_int >("scale", 4, 0, NULL, args, kwargs);
        __ss_int arg_5 = __ss_arg<__ss_int >("max", 5, 0, NULL, args, kwargs);

        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3, arg_4, arg_5));

    } catch (Exception *e) {
        PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
        return 0;
    }
}

static PyNumberMethods Global_mylib_as_number = {
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
};

static PyMethodDef Global_mylibMethods[] = {
    {(char *)"__newobj__", (PyCFunction)__ss__newobj__, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {(char *)"IsCompiled", (PyCFunction)Global_mylib_IsCompiled, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {(char *)"sleep_filter", (PyCFunction)Global_mylib_sleep_filter, METH_VARARGS | METH_KEYWORDS, (char *)""},
    {NULL}
};

PyMODINIT_FUNC initmylib(void) {
    __shedskin__::__init();
    __mylib__::__init();

    __ss_mod_mylib = Py_InitModule((char *)"mylib", Global_mylibMethods);
    if(!__ss_mod_mylib)
        return;


    addmylib();

}

PyMODINIT_FUNC addmylib(void) {
    PyModule_AddObject(__ss_mod_mylib, (char *)"arTest", __to_py(__mylib__::arTest));
    PyModule_AddObject(__ss_mod_mylib, (char *)"arFiltertest", __to_py(__mylib__::arFiltertest));

}

} // namespace __mylib__

} // extern "C"
int main(int, char **) {
    __shedskin__::__init();
    __shedskin__::__start(__mylib__::__init);
}
